@@ -311,14 +311,14 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::RegisterPostCdef()
     allocParamsForBuffer2D.Format   = Format_NV12;
     allocParamsForBuffer2D.dwWidth  = MOS_ALIGN_CEIL(m_basicFeature->m_frameWidth, av1SuperBlockWidth);
     allocParamsForBuffer2D.dwHeight = MOS_ALIGN_CEIL(m_basicFeature->m_frameHeight, av1SuperBlockHeight);
-#ifdef _MMC_SUPPORTED     
+   
     ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
         allocParamsForBuffer2D.CompressionMode = MOS_MMC_MC;
         allocParamsForBuffer2D.bIsCompressible = true;
     }
-#endif   
+  
     if (m_basicFeature->m_is10Bit)
     {
         // This is temporary fix for Sim specific ( Grits Utility) issue, HW has no restriction for current platform
@@ -331,113 +331,6 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::RegisterPostCdef()
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::Submit(
-    MOS_COMMAND_BUFFER *commandBuffer,
-    uint8_t             packetPhase)
-{
-    ENCODE_FUNC_CALL();
-
-    MOS_COMMAND_BUFFER &cmdBuffer = *commandBuffer;
-    ENCODE_CHK_STATUS_RETURN(Mos_Solo_PreProcessEncode(m_osInterface, &m_basicFeature->m_resBitstreamBuffer, &m_basicFeature->m_reconSurface));
-
-    // Ensure the input is ready to be read.
-    // Currently, mos RegisterResource has sync limitation for Raw resource.
-    // Temporaly, call Resource Wait to do the sync explicitly.
-    // TODO, Refine it when MOS refactor ready.
-    MOS_SYNC_PARAMS syncParams;
-    syncParams                  = g_cInitSyncParams;
-    syncParams.GpuContext       = m_osInterface->pfnGetGpuContext(m_osInterface);
-    syncParams.presSyncResource = &m_basicFeature->m_rawSurface.OsResource;
-    syncParams.bReadOnly        = true;
-    ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceWait(m_osInterface, &syncParams));
-    m_osInterface->pfnSetResourceSyncTag(m_osInterface, &syncParams);
-
-    ENCODE_CHK_STATUS_RETURN(RegisterPostCdef());
-
-    ENCODE_CHK_STATUS_RETURN(PatchPictureLevelCommands(packetPhase, cmdBuffer));
-
-    ENCODE_CHK_STATUS_RETURN(PatchTileLevelCommands(cmdBuffer, packetPhase));
-
-    ENCODE_CHK_STATUS_RETURN(PrepareHWMetaData(&cmdBuffer));
-
-    ENCODE_CHK_STATUS_RETURN(Mos_Solo_PostProcessEncode(m_osInterface, &m_basicFeature->m_resBitstreamBuffer, &m_basicFeature->m_reconSurface));
-#if USE_CODECHAL_DEBUG_TOOL
-    ENCODE_CHK_STATUS_RETURN(DumpStatistics());
-#endif  // USE_CODECHAL_DEBUG_TOOL
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::PatchPictureLevelCommands(const uint8_t &packetPhase, MOS_COMMAND_BUFFER &cmdBuffer)
-{
-    ENCODE_FUNC_CALL();
-
-    ENCODE_CHK_STATUS_RETURN(m_miItf->SetWatchdogTimerThreshold(m_basicFeature->m_frameWidth, m_basicFeature->m_frameHeight, true));
-
-    SetPerfTag();
-
-    const bool firstTaskInPhase = packetPhase & firstPacket;
-    const auto brcFeature       = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
-    ENCODE_CHK_NULL_RETURN(brcFeature);
-
-    // if BRC is enabled, MI_FORCE_WAKEUP and prolog commands are added by BRC packet
-    if (firstTaskInPhase || !brcFeature->IsBRCEnabled())
-    {
-        ENCODE_CHK_STATUS_RETURN(AddForceWakeup(cmdBuffer));
-
-        // Send command buffer header at the beginning (OS dependent)
-        ENCODE_CHK_STATUS_RETURN(SendPrologCmds(cmdBuffer));
-    }
-
-    if (m_pipeline->GetPipeNum() >= 2)
-    {
-        auto scalability = m_pipeline->GetMediaScalability();
-
-        ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOtherPipesForOne, 0, &cmdBuffer));
-    }
-
-    ENCODE_CHK_STATUS_RETURN(AddCondBBEndFor2ndPass(cmdBuffer));
-
-    if (m_pipeline->GetPipeNum() >= 2 && m_pipeline->IsFirstPipe())
-    {
-        PMOS_RESOURCE bsSizeBuf = m_basicFeature->m_recycleBuf->GetBuffer(PakInfo, 0);
-        ENCODE_CHK_NULL_RETURN(bsSizeBuf);
-        // clear bitstream size buffer at first tile
-        auto& miStoreDataParams = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
-        miStoreDataParams = {};
-        miStoreDataParams.pOsResource = bsSizeBuf;
-        miStoreDataParams.dwResourceOffset = 0;
-        miStoreDataParams.dwValue = 0;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
-    }
-
-    if (m_pipeline->IsFirstPipe())
-    {
-        ENCODE_CHK_STATUS_RETURN(StartStatusReport(statusReportMfx, &cmdBuffer));
-    }
-    else {
-        // add perf record for other pipes - first pipe perf record within StartStatusReport
-        MediaPerfProfiler* perfProfiler = MediaPerfProfiler::Instance();
-        ENCODE_CHK_NULL_RETURN(perfProfiler);
-        ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectStartCmd(
-            (void*)m_pipeline, m_osInterface, m_miItf, &cmdBuffer));
-    }
-
-    ENCODE_CHK_STATUS_RETURN(AddPictureVdencCommands(cmdBuffer));
-
-    return MOS_STATUS_SUCCESS;
-}
-
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::Construct3rdLevelBatch()
-{
-    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-    //To be added. When BRC is enabled, some of the commands
-    //will be added into 3rd level batch
-
-    return eStatus;
-}
-
 MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
     MOS_COMMAND_BUFFER &cmdBuffer,
     uint32_t            tileRow,
@@ -624,6 +517,8 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddOneTileCommands(
         }
     }
 
+    ENCODE_CHK_STATUS_RETURN(PrepareHWMetaDataFromStreamoutTileLevel(&cmdBuffer, tileCol, tileRow));
+
     return eStatus;
 }
 
@@ -639,278 +534,4 @@ MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::EnsureAllCommandsExecuted(MOS_COMMAND_BU
 
     return MOS_STATUS_SUCCESS;
 }
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::UpdateUserFeatureKey(PMOS_SURFACE surface)
-{
-    if (m_userFeatureUpdated_post_cdef)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-    m_userFeatureUpdated_post_cdef = true;
-
-    ReportUserSetting(
-        m_userSettingPtr,
-        "AV1 Post CDEF Recon Compressible",
-        surface->bCompressible,
-        MediaUserSetting::Group::Sequence);
-    ReportUserSetting(
-        m_userSettingPtr,
-        "AV1 Post CDEF Recon Compress Mode",
-        surface->MmcState,
-        MediaUserSetting::Group::Sequence);
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::PatchTileLevelCommands(MOS_COMMAND_BUFFER &cmdBuffer, uint8_t packetPhase)
-{
-    ENCODE_FUNC_CALL();
-
-    ENCODE_CHK_STATUS_RETURN(Construct3rdLevelBatch());
-
-    uint16_t numTileColumns = 1;
-    uint16_t numTileRows    = 1;
-    RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns, numTileRows, numTileColumns);
-
-    ENCODE_CHK_NULL_RETURN(m_pipeline);
-    ENCODE_CHK_NULL_RETURN(m_av1PicParams);
-    if (!m_pipeline->IsDualEncEnabled())
-    {
-        for (uint32_t tileRow = 0; tileRow < numTileRows; tileRow++)
-        {
-            for (uint32_t tileCol = 0; tileCol < numTileColumns; tileCol++)
-            {
-                ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
-                    cmdBuffer,
-                    tileRow,
-                    tileCol));
-            }
-        }
-    }
-    else
-    {
-        if (numTileRows != 1)  // dual encode only support column based workload submission
-        {
-            ENCODE_ASSERTMESSAGE("dual encode cannot support multi rows submission yet.");
-            return MOS_STATUS_INVALID_PARAMETER;
-        }
-        uint8_t dummyIdx = 0;
-        RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetDummyIdx, dummyIdx);
-        if (m_pipeline->GetCurrentPipe() == 0)
-        {
-            for (auto i = 0; i < dummyIdx; i++)
-            {
-                ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
-                    cmdBuffer,
-                    0,
-                    i));
-            }
-            ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
-                cmdBuffer,
-                0,
-                dummyIdx,
-                1));
-        }
-        else
-        {
-            for (auto i = dummyIdx; i < numTileColumns; i++)
-            {
-                ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
-                    cmdBuffer,
-                    0,
-                    i));
-            }
-        }
-    }
-
-    m_basicFeature->m_flushCmd = Av1BasicFeature::waitAvp;
-    SETPAR_AND_ADDCMD(VD_PIPELINE_FLUSH, m_vdencItf, &cmdBuffer);
-
-    ENCODE_CHK_STATUS_RETURN(EnsureAllCommandsExecuted(cmdBuffer));
-
-    // Wait all pipe cmds done for the packet
-    auto scalability = m_pipeline->GetMediaScalability();
-    ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOnePipeWaitOthers, 0, &cmdBuffer));
-
-    if (m_pipeline->IsFirstPipe())
-    {
-        for (auto i = 0; i < m_pipeline->GetPipeNum(); ++i)
-        {
-            ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, i, &cmdBuffer));
-        }
-        ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
-    }
-    else {
-        // add perf record for other pipes - first pipe perf record within EndStatusReport
-        MediaPerfProfiler* perfProfiler = MediaPerfProfiler::Instance();
-        ENCODE_CHK_NULL_RETURN(perfProfiler);
-        ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectEndCmd(
-            (void*)m_pipeline, m_osInterface, m_miItf, &cmdBuffer));
-    }
-
-    auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
-    ENCODE_CHK_NULL_RETURN(brcFeature);
-
-    if (Mos_Solo_Extension((MOS_CONTEXT_HANDLE)m_osInterface->pOsContext))
-    {
-        ENCODE_CHK_STATUS_RETURN(MediaPacket::UpdateStatusReportNext(statusReportGlobalCount, &cmdBuffer));
-    }
-    else if (brcFeature->IsBRCEnabled() && m_osInterface->bInlineCodecStatusUpdate)
-    {
-        ENCODE_CHK_STATUS_RETURN(UpdateStatusReport(statusReportGlobalCount, &cmdBuffer));
-    }
-    else if (m_pipeline->IsLastPass() && m_pipeline->IsFirstPipe())
-    {
-        ENCODE_CHK_STATUS_RETURN(MediaPacket::UpdateStatusReportNext(statusReportGlobalCount, &cmdBuffer));
-    }
-
-    if (m_pipeline->IsDualEncEnabled())
-    {
-        SETPAR_AND_ADDCMD(VDENC_CONTROL_STATE, m_vdencItf, &cmdBuffer);
-    }
-
-    CODECHAL_DEBUG_TOOL(
-        if (m_mmcState) {
-            m_mmcState->UpdateUserFeatureKey(&(m_basicFeature->m_reconSurface));
-        })
-
-    if (m_av1SeqParams->CodingToolFlags.fields.enable_superres)
-    {
-        PCODEC_REF_LIST currRefList     = m_basicFeature->m_ref.GetCurrRefList();
-        MOS_SURFACE *postCdefSurface = m_basicFeature->m_trackedBuf->GetSurface(
-            BufferType::postCdefReconSurface, currRefList->ucScalingIdx);
-
-        CODECHAL_DEBUG_TOOL(
-            if (m_mmcState) { UpdateUserFeatureKey(postCdefSurface); })
-    }
-
-    UpdateParameters();
-
-    return MOS_STATUS_SUCCESS;
-}
-
-void Av1VdencPktXe_Lpm_Plus_Base::UpdateParameters()
-{
-    ENCODE_FUNC_CALL();
-
-    Av1VdencPkt::UpdateParameters();
-
-    if (!m_pipeline->IsSingleTaskPhaseSupported())
-    {
-        m_osInterface->pfnResetPerfBufferID(m_osInterface);
-    }
-}
-
-
-MHW_SETPAR_DECL_SRC(AVP_PIC_STATE, Av1VdencPktXe_Lpm_Plus_Base)
-{
-    params.notFirstPass = !m_pipeline->IsFirstPass();
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MHW_SETPAR_DECL_SRC(AVP_IND_OBJ_BASE_ADDR_STATE, Av1VdencPktXe_Lpm_Plus_Base)
-{
-    params.mvObjectOffset = m_mvOffset;
-    params.mvObjectSize   = m_basicFeature->m_mbCodeSize - m_mvOffset;
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MHW_SETPAR_DECL_SRC(AVP_TILE_CODING, Av1VdencPktXe_Lpm_Plus_Base)
-{
-    uint32_t tileIdx = 0;
-    RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileIdx, tileIdx);
-    params.disableFrameContextUpdateFlag = m_av1PicParams->PicFlags.fields.disable_frame_end_update_cdf || (tileIdx != m_av1PicParams->context_update_tile_id);
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddAllCmds_AVP_PIPE_MODE_SELECT(PMOS_COMMAND_BUFFER cmdBuffer) const
-{
-    ENCODE_FUNC_CALL();
-
-    ENCODE_CHK_NULL_RETURN(cmdBuffer);
-
-    auto &vdControlStateParams          = m_miItf->MHW_GETPAR_F(VD_CONTROL_STATE)();
-    vdControlStateParams                = {};
-    vdControlStateParams.initialization = true;
-    vdControlStateParams.avpEnabled     = true;
-    ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(VD_CONTROL_STATE)(cmdBuffer));
-
-    SETPAR_AND_ADDCMD(MFX_WAIT, m_miItf, cmdBuffer);
-    SETPAR_AND_ADDCMD(AVP_PIPE_MODE_SELECT, m_avpItf, cmdBuffer);
-    SETPAR_AND_ADDCMD(MFX_WAIT, m_miItf, cmdBuffer);
-
-    if (m_pipeline->GetPipeNum() > 1)
-    {
-        vdControlStateParams                      = {};
-        vdControlStateParams.avpEnabled           = true;
-        vdControlStateParams.scalableModePipeLock = true;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(VD_CONTROL_STATE)(cmdBuffer));
-    }
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::AddAllCmds_AVP_SEGMENT_STATE(PMOS_COMMAND_BUFFER cmdBuffer) const
-{
-    ENCODE_FUNC_CALL();
-
-    ENCODE_CHK_NULL_RETURN(cmdBuffer);
-    ENCODE_CHK_NULL_RETURN(m_featureManager);
-
-    auto &par = m_avpItf->MHW_GETPAR_F(AVP_SEGMENT_STATE)();
-    par      = {};
-
-    auto segmentFeature = dynamic_cast<Av1Segmentation *>(m_featureManager->GetFeature(Av1FeatureIDs::av1Segmentation));
-    ENCODE_CHK_NULL_RETURN(segmentFeature);
-
-    MHW_CHK_STATUS_RETURN(segmentFeature->MHW_SETPAR_F(AVP_SEGMENT_STATE)(par));
-
-    const bool segmentEnabled = par.av1SegmentParams.m_enabled;
-
-    for (uint8_t i = 0; i < av1MaxSegments; i++)
-    {
-        par.currentSegmentId = i;
-        m_avpItf->MHW_ADDCMD_F(AVP_SEGMENT_STATE)(cmdBuffer);
-
-        // If segmentation is not enabled, then AV1_SEGMENT_STATE must still be sent once for SegmentID = 0
-        // If i == numSegments -1, means all segments are issued, break the loop
-        if (!segmentEnabled || (i == par.numSegments - 1))
-        {
-            break;
-        }
-    }
-
-    return MOS_STATUS_SUCCESS;
-}
-
-#if USE_CODECHAL_DEBUG_TOOL
-MOS_STATUS Av1VdencPktXe_Lpm_Plus_Base::DumpStatistics()
-{
-    CodechalDebugInterface* debugInterface = m_pipeline->GetStatusReportDebugInterface();
-    ENCODE_CHK_NULL_RETURN(debugInterface);
-
-    ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
-        m_basicFeature->m_tileStatisticsPakStreamoutBuffer,
-        CodechalDbgAttr::attrTileBasedStats,
-        "Pak_Tile_Stats",
-        512,
-        0,
-        CODECHAL_NUM_MEDIA_STATES));
-
-    MOS_RESOURCE* tileStatisticsBuffer = nullptr;
-    RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, FeatureIDs::encodeTile, GetTileBasedStatisticsBuffer, 0, tileStatisticsBuffer);
-
-    ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
-        tileStatisticsBuffer,
-        CodechalDbgAttr::attrFrameState,
-        "VDEnc_Frame_Stats",
-        m_hwInterface->m_pakIntTileStatsSize,
-        0,
-        CODECHAL_NUM_MEDIA_STATES));
-
-    return MOS_STATUS_SUCCESS;
-}
-#endif  // USE_CODECHAL_DEBUG_TOOL
 }  // namespace encode
