@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2023, Intel Corporation
+* Copyright (c) 2018-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -44,6 +44,16 @@ VpPipeline::VpPipeline(PMOS_INTERFACE osInterface) :
 
 VpPipeline::~VpPipeline()
 {
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (m_reportOnceFlag)
+    {
+        ReportUserSettingForDebug(
+            m_userSettingPtr,
+            __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K_REPORT,
+            0,
+            MediaUserSetting::Group::Sequence);
+    }
+#endif
     // Delete m_featureManager before m_resourceManager, since
     // m_resourceManager is referenced by m_featureManager.
     MOS_Delete(m_featureManager);
@@ -59,8 +69,14 @@ VpPipeline::~VpPipeline()
     DeletePackets();
     DeleteTasks();
 
+    if (m_osInterface && m_osInterface->pfnStopHybridCmdMgr)
+    {
+        m_osInterface->pfnStopHybridCmdMgr(m_osInterface);
+    }
     MOS_Delete(m_vpInterface);
+    MOS_Delete(m_graphManager);
     MOS_Delete(m_kernelSet);
+    MOS_Delete(m_graphSet);
     MOS_Delete(m_paramChecker);
     MOS_Delete(m_mmc);
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -218,8 +234,62 @@ MOS_STATUS VpPipeline::UserFeatureReport()
             {
                 m_reporting->GetFeatures().rtOldCacheSetting = (uint8_t)(m_vpMhwInterface.m_renderHal->oldCacheSettingForTargetSurface);
             }
+            if (m_reporting->GetFeatures().isOcl3DLut)
+            {
+                VP_PUBLIC_NORMALMESSAGE("VP OCL 3DLut Enabled");
+                ReportUserSettingForDebug(
+                    m_userSettingPtr,
+                    __MEDIA_USER_FEATURE_VALUE_VP_OCL_3DLUT_ENABLED,
+                    1,
+                    MediaUserSetting::Group::Sequence);
+            }
 #endif
         }
+#if (_DEBUG || _RELEASE_INTERNAL)
+        if (m_reporting->GetFeatures().isOclFC)
+        {
+            VP_PUBLIC_NORMALMESSAGE("VP OCL FC Supported");
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_SUPPORTED,
+                1,
+                MediaUserSetting::Group::Sequence);
+
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_FEATURE_REPORT,
+                m_reporting->GetFeatures().featureLogOclFC,
+                MediaUserSetting::Group::Sequence);
+
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_REPORT,
+                m_reporting->GetFeatures().diffLogOclFC,
+                MediaUserSetting::Group::Sequence);
+
+            if (m_reporting->GetFeatures().isLegacyFCInUse)
+            {
+                ReportUserSettingForDebug(
+                    m_userSettingPtr,
+                    __MEDIA_USER_FEATURE_VALUE_VP_LEGACY_FC_IN_USE,
+                    1,
+                    MediaUserSetting::Group::Sequence);
+                m_reporting->GetFeatures().isLegacyFCInUse = false;
+            }
+        }
+
+        if (m_reportOnceFlag && m_reporting->GetFeatures().fallbackScalingToRender8K)
+        {
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K_REPORT,
+                1,
+                MediaUserSetting::Group::Sequence);
+            m_reporting->GetFeatures().fallbackScalingToRender8K = false;
+            m_reportOnceFlag                                     = false;
+        }
+        
+#endif
 
         m_reporting->GetFeatures().VPApogeios = m_currentFrameAPGEnabled;
     }
@@ -324,10 +394,17 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
 
     VP_PUBLIC_CHK_STATUS_RETURN(CreatePacketSharedContext());
     VP_PUBLIC_CHK_STATUS_RETURN(CreateVpKernelSets());
+    VP_PUBLIC_CHK_STATUS_RETURN(CreateVpGraphSets());
+    VP_PUBLIC_CHK_STATUS_RETURN(CreateVpGraphManager());
+    if (m_osInterface && m_osInterface->pfnSetHybridMgrSubmitMode && m_userFeatureControl)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(m_osInterface->pfnSetHybridMgrSubmitMode(m_osInterface, m_userFeatureControl->GetHybridMgrSubmitMode()));
+    }
     // Create active tasks
     MediaTask *pTask = GetTask(MediaTask::TaskType::cmdTask);
     VP_PUBLIC_CHK_NULL_RETURN(pTask);
-    VP_PUBLIC_CHK_STATUS_RETURN(m_pPacketFactory->Initialize(pTask, &m_vpMhwInterface, m_allocator, m_mmc, m_packetSharedContext, m_kernelSet, m_debugInterface));
+    
+    VP_PUBLIC_CHK_STATUS_RETURN(m_pPacketFactory->Initialize(pTask, &m_vpMhwInterface, m_allocator, m_mmc, m_packetSharedContext, m_kernelSet, m_debugInterface, m_graphSet));
 
     m_pPacketPipeFactory = MOS_New(PacketPipeFactory, *m_pPacketFactory);
     VP_PUBLIC_CHK_NULL_RETURN(m_pPacketPipeFactory);
@@ -353,12 +430,22 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
             VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(VP_PIPELINE_PACKET_VEBOX, m_scalability,
                 m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
         }
-
-        bool computeContextEnabled = m_userFeatureControl->IsComputeContextEnabled();
-        auto packetId              = computeContextEnabled ? VP_PIPELINE_PACKET_COMPUTE : VP_PIPELINE_PACKET_RENDER;
-        VP_PUBLIC_NORMALMESSAGE("Create GpuContext for Compute/Render (PacketId: %d).", packetId);
-        VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(packetId, m_scalability,
-            m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
+        // If the environment is SA media in which there are no GT IP, we could not create/use Render or Compute GPU context.
+        if (!(m_skuTable && MEDIA_IS_SKU(m_skuTable, FtrDisableGtIpSubmissions)))
+        {
+            bool computeContextEnabled = m_userFeatureControl->IsComputeContextEnabled();
+            auto packetId              = computeContextEnabled ? VP_PIPELINE_PACKET_COMPUTE : VP_PIPELINE_PACKET_RENDER;
+            VP_PUBLIC_NORMALMESSAGE("Create GpuContext for Compute/Render (PacketId: %d).", packetId);
+            VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(packetId, m_scalability,
+                m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
+        }
+        // create SinglePipe GpuContext for multi Vebox system to avoid first frame long latency issue
+        if (m_numVebox > 1 && !(m_vpSettings && m_vpSettings->clearVideoViewMode))
+        {
+            VP_PUBLIC_NORMALMESSAGE("Create Single Pipe GpuContext for Vebox.");
+            VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(VP_PIPELINE_PACKET_VEBOX, m_scalability,
+                m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), 1));
+        }
     }
 
     return MOS_STATUS_SUCCESS;
@@ -377,6 +464,71 @@ bool VpPipeline::IsVeboxSfcFormatSupported(MOS_FORMAT formatInput, MOS_FORMAT fo
     return featureManagerNext->IsVeboxSfcFormatSupported(formatInput, formatOutput);
 }
 
+MOS_STATUS VpPipeline::UpdateRectForNegtiveDstTopLeft(PVP_PIPELINE_PARAMS params)
+{
+    VP_FUNC_CALL();
+
+    for (uint32_t index = 0; (index < params->uSrcCount) && (index < VPHAL_MAX_SOURCES); index++)
+    {
+        PVPHAL_SURFACE pcSrc = params->pSrc[index];
+
+        if (pcSrc)
+        {
+            if (pcSrc->rcDst.top < 0 || pcSrc->rcDst.left < 0)
+            {
+                VP_PUBLIC_NORMALMESSAGE("negtive value on rcDst top or left, top: %d, left: %d.", pcSrc->rcDst.top, pcSrc->rcDst.left);
+                bool isVerticalRotation = VpUtils::IsVerticalRotation(pcSrc->Rotation);
+
+                uint32_t srcHeight = pcSrc->rcSrc.bottom - pcSrc->rcSrc.top;
+                uint32_t srcWidth  = pcSrc->rcSrc.right - pcSrc->rcSrc.left;
+                uint32_t dstHeight = pcSrc->rcDst.bottom - pcSrc->rcDst.top;
+                uint32_t dstWidth  = pcSrc->rcDst.right - pcSrc->rcDst.left;
+
+                float fScaleX = isVerticalRotation ? (float)dstHeight / (float)srcWidth : (float)dstWidth / (float)srcWidth;
+                float fScaleY = isVerticalRotation ? (float)dstWidth / (float)srcHeight : (float)dstHeight / (float)srcHeight;
+
+                if (pcSrc->rcDst.top < 0)
+                {
+                    pcSrc->rcDst.top = 0;
+
+                    if (isVerticalRotation)
+                    {
+                        uint32_t newDstHight = pcSrc->rcDst.bottom;
+                        uint32_t newSrcWidth = MOS_UF_ROUND(newDstHight / fScaleX);
+                        pcSrc->rcSrc.left    = pcSrc->rcSrc.right - newSrcWidth;
+                    }
+                    else
+                    {
+                        uint32_t newDstHight = pcSrc->rcDst.bottom;
+                        uint32_t newSrcHight = MOS_UF_ROUND(newDstHight / fScaleY);
+                        pcSrc->rcSrc.top     = pcSrc->rcSrc.bottom - newSrcHight;
+                    }
+                }
+                if (pcSrc->rcDst.left < 0)
+                {
+                    pcSrc->rcDst.left = 0;
+                    if (isVerticalRotation)
+                    {
+                        uint32_t newDstWidth = pcSrc->rcDst.right;
+                        uint32_t newSrcHight = MOS_UF_ROUND(newDstWidth / fScaleY);
+                        pcSrc->rcSrc.top     = pcSrc->rcSrc.bottom - newSrcHight;
+                    }
+                    else
+                    {
+                        uint32_t newDstWidth = pcSrc->rcDst.right;
+                        uint32_t newSrcWidth = MOS_UF_ROUND(newDstWidth / fScaleX);
+                        pcSrc->rcSrc.left    = pcSrc->rcSrc.right - newSrcWidth;
+                    }
+                }
+                VP_PUBLIC_NORMALMESSAGE("updated source rectangle region: [%d,%d,%d,%d].", pcSrc->rcSrc.left, pcSrc->rcSrc.top, pcSrc->rcSrc.right, pcSrc->rcSrc.bottom);
+                VP_PUBLIC_NORMALMESSAGE("updated destination rectangle region: [%d,%d,%d,%d].", pcSrc->rcDst.left, pcSrc->rcDst.top, pcSrc->rcDst.right, pcSrc->rcDst.bottom);
+            }
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpPipeline::ExecuteVpPipeline()
 {
     VP_FUNC_CALL();
@@ -398,12 +550,16 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
     }
 
-    MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_START, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(), MT_VP_FEATURE_GRAPH_FILTER_FRAMEID,m_vpPipeContexts[0]->GetFrameCounter());
+    MT_LOG1(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_START, MT_NORMAL,
+            MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size());
+    VP_PUBLIC_NORMALMESSAGE("Feature Graph: Execute VP Pipeline Start, swfilterPipes count:%d", (int64_t)swFilterPipes.size());
 
     if (PIPELINE_PARAM_TYPE_LEGACY == m_pvpParams.type)
     {
         params = m_pvpParams.renderParams;
         VP_PUBLIC_CHK_NULL_RETURN(params);
+        // Get the OptimizeCpuTiming flag from params
+        m_osInterface->bOptimizeCpuTiming = params->bOptimizeCpuTiming;
         // Set Pipeline status Table
         m_statusReport->SetPipeStatusReportParams(params, m_vpMhwInterface.m_statusTable);
 
@@ -422,6 +578,7 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
                 VPHAL_SURF_DUMP_DDI_VP_BLT);
         }
 #endif
+        UpdateRectForNegtiveDstTopLeft(params);
         // Predication
         SetPredicationParams(params);
 
@@ -429,12 +586,16 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
         VP_PUBLIC_CHK_STATUS_RETURN(eStatus);
         if (isBypassNeeded)
         {
-            MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
-                    MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
+            MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL, 
+                    MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+                    MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
+            VP_PUBLIC_NORMALMESSAGE("Feature Graph: Execute VP Pipeline End, swfilterPipes count:%d, isBypassNeeded:%d",
+                                     (int64_t)swFilterPipes.size(),
+                                     isBypassNeeded);
             return MOS_STATUS_SUCCESS;
         }
     }
-
+    VP_PUBLIC_CHK_STATUS_RETURN(UpdateFrameTracker());
     VP_PUBLIC_CHK_STATUS_RETURN(CreateSwFilterPipe(m_pvpParams, swFilterPipes));
 
     // Increment frame ID for performance measurement
@@ -442,29 +603,41 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
 
     for (uint32_t pipeIdx = 0; pipeIdx < swFilterPipes.size(); pipeIdx++)
     {
-        MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_START, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
-                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
         auto &pipe = swFilterPipes[pipeIdx];
-        if (pipe)
-        {
-            pipe->AddRTLog();
-        }
         if (pipeIdx >= m_vpPipeContexts.size())
         {
             VP_PUBLIC_CHK_STATUS_RETURN(CreateSinglePipeContext());
         }
-
+        MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_START, MT_NORMAL,
+                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[pipeIdx]->GetFrameCounter(),
+                MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
+        VP_PUBLIC_NORMALMESSAGE("Feature Graph: Execute VP Single Pipeline Start, frameid:%d, pipeid:%d",
+                                 m_vpPipeContexts[pipeIdx]->GetFrameCounter(),
+                                 pipeIdx);
+        if (pipe)
+        {
+            pipe->AddRTLog();
+        }
         auto &singlePipeCtx = m_vpPipeContexts[pipeIdx];
         VP_PUBLIC_CHK_NULL_RETURN(singlePipeCtx->GetVpResourceManager());
         VP_PUBLIC_CHK_STATUS_RETURN(m_vpInterface->SwitchResourceManager(singlePipeCtx->GetVpResourceManager()));
 
         VP_PUBLIC_CHK_STATUS_RETURN(ExecuteSingleswFilterPipe(singlePipeCtx, pipe, pPacketPipe, featureManagerNext));
-        MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
-                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
+        // FrameCounter will be increased inside ExecuteSingleswFilterPipe, so m_vpPipeContexts[pipeIdx]->GetFrameCounter() - 1 is needed.
+        MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_END, MT_NORMAL,
+                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[pipeIdx]->GetFrameCounter() - 1,
+                MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
+        VP_PUBLIC_NORMALMESSAGE("Feature Graph: Execute VP Single Pipeline End, frameid:%d, pipeid:%d",
+                                 m_vpPipeContexts[pipeIdx]->GetFrameCounter() - 1,
+                                 pipeIdx);
     }
 
-    MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
-            MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
+    MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL,
+            MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+            MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
+    VP_PUBLIC_NORMALMESSAGE("Feature Graph: Execute VP Pipeline End, swfilterPipes count:%d, isBypassNeeded:%d",
+                             (int64_t)swFilterPipes.size(),
+                             isBypassNeeded);
     return eStatus;
 }
 
@@ -501,7 +674,7 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
         }
         return p;
     };
-
+    uint64_t gpuCtxOnHybridCmd = pipe->GetGpuCtxOnHybridCmd();
     // Notify resourceManager for start of new frame processing.
     MT_LOG1(MT_VP_HAL_ONNEWFRAME_PROC_START, MT_NORMAL, MT_VP_HAL_ONNEWFRAME_COUNTER, frameCounter);
     VP_PUBLIC_CHK_STATUS_RETURN(chkStatusHandler(resourceManager->OnNewFrameProcessStart(*pipe)));
@@ -526,7 +699,7 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
         singlePipeCtx->SetOutputPipeMode(pipeReused->GetOutputPipeMode());
         singlePipeCtx->SetIsVeboxFeatureInuse(pipeReused->IsVeboxFeatureInuse());
         // MediaPipeline::m_statusReport is always nullptr in VP APO path right now.
-        eStatus = pipeReused->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox);
+        eStatus = pipeReused->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox, gpuCtxOnHybridCmd, frameCounter);
         MT_LOG1(MT_VP_HAL_VEBOXNUM_CHECK, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
         VP_PUBLIC_NORMALMESSAGE("Vebox Number for check %d", m_numVebox);
         if (MOS_SUCCEEDED(eStatus))
@@ -560,7 +733,9 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
     singlePipeCtx->SetIsVeboxFeatureInuse(pPacketPipe->IsVeboxFeatureInuse());
 
     // MediaPipeline::m_statusReport is always nullptr in VP APO path right now.
-    eStatus = pPacketPipe->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox);
+
+    eStatus = pPacketPipe->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox, gpuCtxOnHybridCmd, frameCounter);
+
     MT_LOG1(MT_VP_HAL_VEBOXNUM_CHECK, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
     VP_PUBLIC_NORMALMESSAGE("Vebox Number for check %d", m_numVebox);
     if (MOS_SUCCEEDED(eStatus))
@@ -568,7 +743,7 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
         VP_PUBLIC_CHK_STATUS_RETURN(chkStatusHandler(packetReuseMgr->UpdatePacketPipeConfig(pPacketPipe)));
         VP_PUBLIC_CHK_STATUS_RETURN(chkStatusHandler(UpdateExecuteStatus(frameCounter)));
     }
-
+    
     m_pPacketPipeFactory->ReturnPacketPipe(pPacketPipe);
     retHandler();
 
@@ -632,6 +807,15 @@ MOS_STATUS VpPipeline::CreateSwFilterPipe(VP_PARAMS &params, std::vector<SwFilte
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS VpPipeline::UpdateFrameTracker()
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_NULL_RETURN(m_vpMhwInterface.m_vpPlatformInterface);
+    VP_PUBLIC_CHK_STATUS_RETURN(m_vpMhwInterface.m_vpPlatformInterface->InitFrameTracker());
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpPipeline::UpdateVeboxNumberforScalability()
 {
     VP_FUNC_CALL();
@@ -730,7 +914,7 @@ MOS_STATUS VpPipeline::CreateSinglePipeContext()
     VP_FUNC_CALL();
     VpSinglePipeContext *singlePipeCtx = MOS_New(VpSinglePipeContext);
     VP_PUBLIC_CHK_NULL_RETURN(singlePipeCtx);
-    MOS_STATUS status = singlePipeCtx->Init(m_osInterface, m_allocator, m_reporting, m_vpMhwInterface.m_vpPlatformInterface, m_pPacketPipeFactory, m_userFeatureControl, m_mediaCopyWrapper);
+    MOS_STATUS status = singlePipeCtx->Init(m_osInterface, m_allocator, m_reporting, m_vpMhwInterface.m_vpPlatformInterface, m_pPacketPipeFactory, m_userFeatureControl, m_mediaCopyWrapper, m_graphManager);
     if (MOS_FAILED(status))
     {
         MOS_Delete(singlePipeCtx);
@@ -757,7 +941,7 @@ MOS_STATUS VpPipeline::CreateFeatureManager(VpResourceManager *vpResourceManager
     m_paramChecker = m_vpMhwInterface.m_vpPlatformInterface->CreateFeatureChecker(&m_vpMhwInterface);
     VP_PUBLIC_CHK_NULL_RETURN(m_paramChecker);
 
-    m_vpInterface = MOS_New(VpInterface, &m_vpMhwInterface, *m_allocator, vpResourceManager);
+    m_vpInterface = MOS_New(VpInterface, &m_vpMhwInterface, *m_allocator, vpResourceManager, m_graphManager);
 
     VP_PUBLIC_CHK_NULL_RETURN(m_vpInterface);
 
@@ -783,6 +967,26 @@ MOS_STATUS VpPipeline::CreateVpKernelSets()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS VpPipeline::CreateVpGraphSets()
+{
+    if (nullptr == m_graphSet)
+    {
+        m_graphSet = MOS_New(VpGraphSet, &m_vpMhwInterface, m_allocator);
+        VP_PUBLIC_CHK_NULL_RETURN(m_graphSet);
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpPipeline::CreateVpGraphManager()
+{
+    if (nullptr == m_graphManager)
+    {
+        m_graphManager = MOS_New(VpGraphManager, m_graphSet, m_osInterface, m_allocator);
+        VP_PUBLIC_CHK_NULL_RETURN(m_graphManager);
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpPipeline::CheckFeatures(void *params, bool &bapgFuncSupported)
 {
     VP_FUNC_CALL();
@@ -1056,10 +1260,9 @@ MOS_STATUS VpPipeline::PrepareVpPipelineParams(PVP_PIPELINE_PARAMS params)
 MOS_STATUS VpPipeline::PrepareVpPipelineScalabilityParams(uint32_t srcWidth, uint32_t srcHeight, uint32_t dstWidth, uint32_t dstHeight)
 {
     VP_FUNC_CALL();
-
     VP_PUBLIC_NORMALMESSAGE("Reset m_numVebox %d -> %d", m_numVebox, m_numVeboxOriginal);
     m_numVebox = m_numVeboxOriginal;
-    MT_LOG1(MT_VP_HAL_VEBOXNUM_CHECK, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
+    MT_LOG1(MT_VP_HAL_VEBOXNUM_RESET, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
 
     // Disable vesfc scalability when reg key "Enable Vebox Scalability" was set to zero
     if (m_forceMultiplePipe == (MOS_SCALABILITY_ENABLE_MODE_USER_FORCE | MOS_SCALABILITY_ENABLE_MODE_FALSE))
@@ -1232,10 +1435,10 @@ VpSinglePipeContext::~VpSinglePipeContext()
     MOS_Delete(m_resourceManager);
 }
 
-MOS_STATUS VpSinglePipeContext::Init(PMOS_INTERFACE osInterface, VpAllocator *allocator, VphalFeatureReport *reporting, vp::VpPlatformInterface *vpPlatformInterface, PacketPipeFactory *packetPipeFactory, VpUserFeatureControl *userFeatureControl, MediaCopyWrapper *mediaCopyWrapper)
+MOS_STATUS VpSinglePipeContext::Init(PMOS_INTERFACE osInterface, VpAllocator *allocator, VphalFeatureReport *reporting, vp::VpPlatformInterface *vpPlatformInterface, PacketPipeFactory *packetPipeFactory, VpUserFeatureControl *userFeatureControl, MediaCopyWrapper *mediaCopyWrapper, VpGraphManager *graphManager)
 {
     VP_FUNC_CALL();
-    VP_PUBLIC_CHK_STATUS_RETURN(CreateResourceManager(osInterface, allocator, reporting, vpPlatformInterface, userFeatureControl, mediaCopyWrapper));
+    VP_PUBLIC_CHK_STATUS_RETURN(CreateResourceManager(osInterface, allocator, reporting, vpPlatformInterface, userFeatureControl, mediaCopyWrapper, graphManager));
     VP_PUBLIC_CHK_NULL_RETURN(m_resourceManager);
     VP_PUBLIC_CHK_STATUS_RETURN(CreatePacketReuseManager(packetPipeFactory, userFeatureControl));
     VP_PUBLIC_CHK_NULL_RETURN(m_packetReuseMgr);
@@ -1248,12 +1451,12 @@ MOS_STATUS VpSinglePipeContext::Init(PMOS_INTERFACE osInterface, VpAllocator *al
 //! \return MOS_STATUS
 //!         MOS_STATUS_SUCCESS if success, else fail reason
 //!
-MOS_STATUS VpSinglePipeContext::CreateResourceManager(PMOS_INTERFACE osInterface, VpAllocator *allocator, VphalFeatureReport *reporting, vp::VpPlatformInterface *vpPlatformInterface, vp::VpUserFeatureControl *userFeatureControl, MediaCopyWrapper *mediaCopyWrapper)
+MOS_STATUS VpSinglePipeContext::CreateResourceManager(PMOS_INTERFACE osInterface, VpAllocator *allocator, VphalFeatureReport *reporting, vp::VpPlatformInterface *vpPlatformInterface, vp::VpUserFeatureControl *userFeatureControl, MediaCopyWrapper *mediaCopyWrapper, VpGraphManager *graphManager)
 {
     VP_FUNC_CALL();
     if (nullptr == m_resourceManager)
     {
-        m_resourceManager = MOS_New(VpResourceManager, *osInterface, *allocator, *reporting, *vpPlatformInterface, mediaCopyWrapper, userFeatureControl);
+        m_resourceManager = MOS_New(VpResourceManager, *osInterface, *allocator, *reporting, *vpPlatformInterface, mediaCopyWrapper, userFeatureControl, graphManager);
         VP_PUBLIC_CHK_NULL_RETURN(m_resourceManager);
     }
     
